Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func WriteDockerfile ¶
func WriteDockerfile(dir string, env *Environment) (string, error)
WriteDockerfile writes Dockerfile.test (and Dockerfile.test.dockerignore if needed) to dir and returns the path to the written Dockerfile.
Types ¶
type Environment ¶
type Environment struct {
Stack string `json:"stack"`
Install string `json:"install"`
Test string `json:"test"`
SystemDeps []string `json:"system_deps"`
Image string `json:"image"`
ImageVersion string `json:"image_version"`
}
Environment describes the detected tech stack and build configuration for a repository.
func DetectEnvironment ¶
func DetectEnvironment(ctx context.Context, dir string) (*Environment, error)
DetectEnvironment analyses the repository at dir and returns a detected Environment.
Click to show internal directories.
Click to hide internal directories.