binary

package
v0.7.15 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 9, 2026 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BuildBinary

func BuildBinary() (string, error)

BuildBinary compiles the chunk CLI binary once and returns its path. Call from TestMain.

func Path

func Path() string

Path returns the path to the compiled binary. Must call BuildBinary first.

Types

type CLIResult

type CLIResult struct {
	Stdout   string
	Stderr   string
	ExitCode int
}

CLIResult holds the output of a CLI invocation.

func RunCLI

func RunCLI(t *testing.T, args []string, e *env.TestEnv, workDir string) CLIResult

RunCLI executes the chunk binary with the given args, env, and working directory.

func RunCLIWithStdin

func RunCLIWithStdin(t *testing.T, args []string, e *env.TestEnv, workDir string, stdin []byte) CLIResult

RunCLIWithStdin executes the chunk binary with the given args, env, working directory, and optional stdin data.

Jump to